@@ -19,8 +19,6 @@ from airflow.models.dag import DAG
 from airflow.models.dagbag import DagBag
 from airflow.settings import LOG_FORMAT
 from airflow.utils import db
-from dagster_airflow.patch_airflow_example_dag import patch_airflow_example_dag
-
 from dagster import (
     Array,
     DagsterInvariantViolationError,
@@ -32,15 +30,19 @@ from dagster import (
     Nothing,
     Out,
     ScheduleDefinition,
+    _check as check,
+    op,
+    repository,
+    resource,
 )
-from dagster import _check as check
-from dagster import op, repository, resource
 from dagster._core.definitions.op_definition import OpDefinition
 from dagster._core.definitions.utils import VALID_NAME_REGEX, validate_tags
 from dagster._core.instance import AIRFLOW_EXECUTION_DATE_STR, IS_AIRFLOW_INGEST_PIPELINE_STR
 from dagster._legacy import ModeDefinition, PipelineDefinition
 from dagster._utils.schedules import is_valid_cron_schedule
 
+from dagster_airflow.patch_airflow_example_dag import patch_airflow_example_dag
+
 # pylint: disable=no-name-in-module,import-error
 if str(airflow_version) >= "2.0.0":
     from airflow.utils.session import create_session
@@ -285,7 +287,10 @@ def make_dagster_schedule_from_airflow_dag(dag, job_def):
 
     if isinstance(dag.normalized_schedule_interval, str) and is_valid_cron_schedule(cron_schedule):
         return ScheduleDefinition(
-            job=job_def, cron_schedule=cron_schedule, description=schedule_description
+            job=job_def,
+            cron_schedule=cron_schedule,
+            description=schedule_description,
+            execution_timezone=dag.timezone.name,
         )
 
 
@@ -777,7 +782,8 @@ def make_dagster_solid_from_airflow_task(
             )
         except OverflowError:
             raise DagsterInvariantViolationError(
-                'Date "{execution_date_str}" exceeds the largest valid C integer on the system.'.format(
+                'Date "{execution_date_str}" exceeds the largest valid C integer on the system.'
+                .format(
                     execution_date_str=execution_date_str,
                 )
             )
@@ -830,7 +836,8 @@ def make_dagster_solid_from_airflow_task(
 
 def dagster_get_template_context(task_instance, task, execution_date):
     """
-    Modified from /airflow/models/taskinstance.py to not reference Airflow DB
+    Modified from /airflow/models/taskinstance.py to not reference Airflow DB.
+
     (1) Removes the following block, which queries DB, removes dagrun instances, recycles run_id
     if hasattr(task, 'dag'):
         if task.dag.params:
